@@ -1,6 +1,5 @@
 import os.path
 import shutil
-import sys
 import time
 from pathlib import Path
 
@@ -33,7 +32,7 @@ class Syncer:
                 logging.log(f"Reading hashes from {self.hash_file}")
             else:
                 self.dst_hashes = HashTracker(dst)
-                self.hash_file.write_text(self.dst_hashes.serialise())
+                self.write_text(hash_file, self.dst_hashes.serialise())
                 logging.log(f"Creating empty hashes file at {self.hash_file}")
 
     def _check_wrong_file_type(self, dst: Path, should_be_dir: bool) -> bool:
@@ -41,6 +40,9 @@ class Syncer:
             if not self.do_delete:
                 return True
 
+            if self.is_protected(dst):
+                return False
+
             if self.advanced_output_features:
                 terminal_formatting.hide_temp()
 
@@ -64,19 +66,16 @@ class Syncer:
         dst.mkdir(parents=True, exist_ok=True)
 
         if self.do_delete:
-            for item in dst.iterdir():
-                sub_path = item.relative_to(dst)
-                self.visit(sub_path)
+            for item in os.listdir(dst):
+                self.visit(path / item)
 
-        for item in src.iterdir():
-            sub_path = item.relative_to(src)
-            self.visit(sub_path)
+        for item in os.listdir(src):
+            self.visit(path / item)
 
         self.update_hashes(path)
 
     def update_hashes(self, path: Path):
         if self.use_hashes:
-            # print(f"Updating hash for {path}")
             self.dst_hashes.update_hash(path, self.src_hashes)
 
     def check_hashes(self, path: Path) -> bool:
@@ -103,7 +102,6 @@ class Syncer:
         return self.force
 
     def autosave_hashes(self, force=False):
-
         if not self.use_hashes:
             return
         if not (force or time.time() - self.last_autosave_time >= 2):
@@ -112,7 +110,7 @@ class Syncer:
         self.last_autosave_time = time.time()
 
         terminal_formatting.print_temp(f"Saving hashes to {self.hash_file}")
-        self.hash_file.write_text(self.dst_hashes.serialise())
+        self.write_text(hash_file, self.dst_hashes.serialise())
 
     def visit_file(self, path: Path):
         src = self.src / path
@@ -121,9 +119,7 @@ class Syncer:
         if self._check_wrong_file_type(dst, False):
             return
 
-        # print("a")
         if self.should_copy(path):
-            # print("b")
             self.copy_file(src, dst)
             self.update_hashes(path)
 
@@ -133,9 +129,12 @@ class Syncer:
         src = self.src / path
 
         if not src.exists():
-            if not do_delete: return
+            if not self.do_delete: return
 
             dst = self.dst / path
+            if self.is_protected(dst):
+                return
+
             if self.advanced_output_features:
                 terminal_formatting.hide_temp()
             if self.verbose:
@@ -154,6 +153,9 @@ class Syncer:
         if self.advanced_output_features:
             terminal_formatting.hide_temp()
 
+    def is_protected(self, path: Path):
+        return not self.use_hashes or path == self.hash_file
+
     @staticmethod
     def copy_file(src: Path, dest: Path):
         """
@@ -163,6 +165,11 @@ class Syncer:
         dest.unlink(missing_ok=True)
         shutil.copyfile(src, dest)
 
+    @staticmethod
+    def write_text(dst: Path, text: str):
+        dst.unlink(missing_ok=True)
+        dst.write_text(text)
+
     @staticmethod
     def delete_path(file: Path):
         """
