@@ -62,7 +62,7 @@ class HashTracker:
         tracker = HashTracker(relative_to)
 
         for path, hash_value in hashes.items():
-            tracker.hashes[path] = hash_value
+            tracker.hashes[Path(path)] = hash_value
 
         return tracker
 
